# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.condition_group_validate_result import ConditionGroupValidateResult


class ItemPurchaseConditionValidateResult(Model):
    """Item purchase condition validate result (ItemPurchaseConditionValidateResult)

    Properties:
        item_id: (itemId) OPTIONAL str

        purchasable: (purchasable) OPTIONAL bool

        sku: (sku) OPTIONAL str

        validate_details: (validateDetails) OPTIONAL List[ConditionGroupValidateResult]
    """

    # region fields

    item_id: str  # OPTIONAL
    purchasable: bool  # OPTIONAL
    sku: str  # OPTIONAL
    validate_details: List[ConditionGroupValidateResult]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_item_id(self, value: str) -> ItemPurchaseConditionValidateResult:
        self.item_id = value
        return self

    def with_purchasable(self, value: bool) -> ItemPurchaseConditionValidateResult:
        self.purchasable = value
        return self

    def with_sku(self, value: str) -> ItemPurchaseConditionValidateResult:
        self.sku = value
        return self

    def with_validate_details(
        self, value: List[ConditionGroupValidateResult]
    ) -> ItemPurchaseConditionValidateResult:
        self.validate_details = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "item_id"):
            result["itemId"] = str(self.item_id)
        elif include_empty:
            result["itemId"] = ""
        if hasattr(self, "purchasable"):
            result["purchasable"] = bool(self.purchasable)
        elif include_empty:
            result["purchasable"] = False
        if hasattr(self, "sku"):
            result["sku"] = str(self.sku)
        elif include_empty:
            result["sku"] = ""
        if hasattr(self, "validate_details"):
            result["validateDetails"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.validate_details
            ]
        elif include_empty:
            result["validateDetails"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        item_id: Optional[str] = None,
        purchasable: Optional[bool] = None,
        sku: Optional[str] = None,
        validate_details: Optional[List[ConditionGroupValidateResult]] = None,
        **kwargs,
    ) -> ItemPurchaseConditionValidateResult:
        instance = cls()
        if item_id is not None:
            instance.item_id = item_id
        if purchasable is not None:
            instance.purchasable = purchasable
        if sku is not None:
            instance.sku = sku
        if validate_details is not None:
            instance.validate_details = validate_details
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ItemPurchaseConditionValidateResult:
        instance = cls()
        if not dict_:
            return instance
        if "itemId" in dict_ and dict_["itemId"] is not None:
            instance.item_id = str(dict_["itemId"])
        elif include_empty:
            instance.item_id = ""
        if "purchasable" in dict_ and dict_["purchasable"] is not None:
            instance.purchasable = bool(dict_["purchasable"])
        elif include_empty:
            instance.purchasable = False
        if "sku" in dict_ and dict_["sku"] is not None:
            instance.sku = str(dict_["sku"])
        elif include_empty:
            instance.sku = ""
        if "validateDetails" in dict_ and dict_["validateDetails"] is not None:
            instance.validate_details = [
                ConditionGroupValidateResult.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["validateDetails"]
            ]
        elif include_empty:
            instance.validate_details = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ItemPurchaseConditionValidateResult]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ItemPurchaseConditionValidateResult]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ItemPurchaseConditionValidateResult,
        List[ItemPurchaseConditionValidateResult],
        Dict[Any, ItemPurchaseConditionValidateResult],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "itemId": "item_id",
            "purchasable": "purchasable",
            "sku": "sku",
            "validateDetails": "validate_details",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "itemId": False,
            "purchasable": False,
            "sku": False,
            "validateDetails": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Match Service V2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.api_proposed_proposal import ApiProposedProposal


class ApiMatchTicketStatus(Model):
    """Api match ticket status (api.MatchTicketStatus)

    Properties:
        match_found: (matchFound) REQUIRED bool

        session_id: (sessionID) REQUIRED str

        match_pool: (matchPool) OPTIONAL str

        match_ticket_id: (matchTicketID) OPTIONAL str

        proposed_proposal: (proposedProposal) OPTIONAL ApiProposedProposal
    """

    # region fields

    match_found: bool  # REQUIRED
    session_id: str  # REQUIRED
    match_pool: str  # OPTIONAL
    match_ticket_id: str  # OPTIONAL
    proposed_proposal: ApiProposedProposal  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_match_found(self, value: bool) -> ApiMatchTicketStatus:
        self.match_found = value
        return self

    def with_session_id(self, value: str) -> ApiMatchTicketStatus:
        self.session_id = value
        return self

    def with_match_pool(self, value: str) -> ApiMatchTicketStatus:
        self.match_pool = value
        return self

    def with_match_ticket_id(self, value: str) -> ApiMatchTicketStatus:
        self.match_ticket_id = value
        return self

    def with_proposed_proposal(
        self, value: ApiProposedProposal
    ) -> ApiMatchTicketStatus:
        self.proposed_proposal = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "match_found"):
            result["matchFound"] = bool(self.match_found)
        elif include_empty:
            result["matchFound"] = False
        if hasattr(self, "session_id"):
            result["sessionID"] = str(self.session_id)
        elif include_empty:
            result["sessionID"] = ""
        if hasattr(self, "match_pool"):
            result["matchPool"] = str(self.match_pool)
        elif include_empty:
            result["matchPool"] = ""
        if hasattr(self, "match_ticket_id"):
            result["matchTicketID"] = str(self.match_ticket_id)
        elif include_empty:
            result["matchTicketID"] = ""
        if hasattr(self, "proposed_proposal"):
            result["proposedProposal"] = self.proposed_proposal.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["proposedProposal"] = ApiProposedProposal()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        match_found: bool,
        session_id: str,
        match_pool: Optional[str] = None,
        match_ticket_id: Optional[str] = None,
        proposed_proposal: Optional[ApiProposedProposal] = None,
        **kwargs,
    ) -> ApiMatchTicketStatus:
        instance = cls()
        instance.match_found = match_found
        instance.session_id = session_id
        if match_pool is not None:
            instance.match_pool = match_pool
        if match_ticket_id is not None:
            instance.match_ticket_id = match_ticket_id
        if proposed_proposal is not None:
            instance.proposed_proposal = proposed_proposal
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiMatchTicketStatus:
        instance = cls()
        if not dict_:
            return instance
        if "matchFound" in dict_ and dict_["matchFound"] is not None:
            instance.match_found = bool(dict_["matchFound"])
        elif include_empty:
            instance.match_found = False
        if "sessionID" in dict_ and dict_["sessionID"] is not None:
            instance.session_id = str(dict_["sessionID"])
        elif include_empty:
            instance.session_id = ""
        if "matchPool" in dict_ and dict_["matchPool"] is not None:
            instance.match_pool = str(dict_["matchPool"])
        elif include_empty:
            instance.match_pool = ""
        if "matchTicketID" in dict_ and dict_["matchTicketID"] is not None:
            instance.match_ticket_id = str(dict_["matchTicketID"])
        elif include_empty:
            instance.match_ticket_id = ""
        if "proposedProposal" in dict_ and dict_["proposedProposal"] is not None:
            instance.proposed_proposal = ApiProposedProposal.create_from_dict(
                dict_["proposedProposal"], include_empty=include_empty
            )
        elif include_empty:
            instance.proposed_proposal = ApiProposedProposal()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiMatchTicketStatus]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiMatchTicketStatus]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiMatchTicketStatus,
        List[ApiMatchTicketStatus],
        Dict[Any, ApiMatchTicketStatus],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "matchFound": "match_found",
            "sessionID": "session_id",
            "matchPool": "match_pool",
            "matchTicketID": "match_ticket_id",
            "proposedProposal": "proposed_proposal",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "matchFound": True,
            "sessionID": True,
            "matchPool": False,
            "matchTicketID": False,
            "proposedProposal": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Chat Service."""

__version__ = "0.4.29"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_profanity_create import AdminProfanityCreate
from .admin_profanity_create_bulk import AdminProfanityCreateBulk
from .admin_profanity_delete import AdminProfanityDelete
from .admin_profanity_export import AdminProfanityExport
from .admin_profanity_group import AdminProfanityGroup
from .admin_profanity_import import AdminProfanityImport
from .admin_profanity_import import ActionEnum as AdminProfanityImportActionEnum
from .admin_profanity_query import AdminProfanityQuery
from .admin_profanity_update import AdminProfanityUpdate



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Browser Service."""

__version__ = "1.18.7"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .models_active_custom_game_response import ModelsActiveCustomGameResponse
from .models_active_matchmaking_game_response import ModelsActiveMatchmakingGameResponse
from .models_add_player_request import ModelsAddPlayerRequest
from .models_add_player_response import ModelsAddPlayerResponse
from .models_admin_session_response import ModelsAdminSessionResponse
from .models_count_active_session_response import ModelsCountActiveSessionResponse
from .models_create_session_request import ModelsCreateSessionRequest
from .models_custom_game_response import ModelsCustomGameResponse
from .models_game_session import ModelsGameSession
from .models_game_session_setting import ModelsGameSessionSetting
from .models_get_session_history_detailed_response_item import (
    ModelsGetSessionHistoryDetailedResponseItem,
)
from .models_get_session_history_search_response_item_v2 import (
    ModelsGetSessionHistorySearchResponseItemV2,
)
from .models_get_session_history_search_response_v2 import (
    ModelsGetSessionHistorySearchResponseV2,
)
from .models_join_game_session_request import ModelsJoinGameSessionRequest
from .models_match_attributes import ModelsMatchAttributes
from .models_match_making import ModelsMatchMaking
from .models_matching_ally import ModelsMatchingAlly
from .models_matching_party import ModelsMatchingParty
from .models_pagination import ModelsPagination
from .models_paging_cursor import ModelsPagingCursor
from .models_party_member import ModelsPartyMember
from .models_recent_player_history import ModelsRecentPlayerHistory
from .models_recent_player_query_response import ModelsRecentPlayerQueryResponse
from .models_server import ModelsServer
from .models_session_by_user_i_ds_response import ModelsSessionByUserIDsResponse
from .models_session_player_history import ModelsSessionPlayerHistory
from .models_session_player_joining import ModelsSessionPlayerJoining
from .models_session_query_response import ModelsSessionQueryResponse
from .models_session_response import ModelsSessionResponse
from .models_status_history import ModelsStatusHistory
from .models_update_session_request import ModelsUpdateSessionRequest
from .models_update_settings_request import ModelsUpdateSettingsRequest
from .response_error import ResponseError
from .restapi_error_response_v2 import RestapiErrorResponseV2
from .restapi_error_v1 import RestapiErrorV1



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsEventResponseV2
from ..models import ModelsGenericQueryPayload

from ..operations.event_v2 import GetEventSpecificUserV2Handler
from ..operations.event_v2 import GetPublicEditHistory
from ..operations.event_v2 import GetUserEventsV2Public
from ..operations.event_v2 import QueryEventStreamHandler


@same_doc_as(GetEventSpecificUserV2Handler)
def get_event_specific_user_v2_handler(
    user_id: str,
    end_date: Optional[str] = None,
    event_name: Optional[str] = None,
    offset: Optional[int] = None,
    page_size: Optional[int] = None,
    start_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get events from a specific user (GetEventSpecificUserV2Handler)

    Get events from a specific user

    Properties:
        url: /event/v2/admin/namespaces/{namespace}/users/{userId}/event

        method: GET

        tags: ["Event V2"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        event_name: (eventName) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        page_size: (pageSize) OPTIONAL int in query

        start_date: (startDate) OPTIONAL str in query

    Responses:
        200: OK - ModelsEventResponseV2 (OK)

        400: Bad Request - (Bad Request)

        401: Unauthorized - (Unauthorized)

        403: Forbidden - (Forbidden)

        404: Not Found - (Not Found)

        500: Internal Server Error - (Internal Server Error)

        501: Not Implemented - (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetEventSpecificUserV2Handler.create(
        user_id=user_id,
        end_date=end_date,
        event_name=event_name,
        offset=offset,
        page_size=page_size,
        start_date=start_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetEventSpecificUserV2Handler)
async def get_event_specific_user_v2_handler_async(
    user_id: str,
    end_date: Optional[str] = None,
    event_name: Optional[str] = None,
    offset: Optional[int] = None,
    page_size: Optional[int] = None,
    start_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get events from a specific user (GetEventSpecificUserV2Handler)

    Get events from a specific user

    Properties:
        url: /event/v2/admin/namespaces/{namespace}/users/{userId}/event

        method: GET

        tags: ["Event V2"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        event_name: (eventName) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        page_size: (pageSize) OPTIONAL int in query

        start_date: (startDate) OPTIONAL str in query

    Responses:
        200: OK - ModelsEventResponseV2 (OK)

        400: Bad Request - (Bad Request)

        401: Unauthorized - (Unauthorized)

        403: Forbidden - (Forbidden)

        404: Not Found - (Not Found)

        500: Internal Server Error - (Internal Server Error)

        501: Not Implemented - (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetEventSpecificUserV2Handler.create(
        user_id=user_id,
        end_date=end_date,
        event_name=event_name,
        offset=offset,
        page_size=page_size,
        start_date=start_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetPublicEditHistory)
def get_public_edit_history(
    user_id: str,
    end_date: Optional[str] = None,
    offset: Optional[int] = None,
    page_size: Optional[int] = None,
    start_date: Optional[str] = None,
    type_: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get a user edit history based on the provided type (GetPublicEditHistory)

    Available Type:
    * email
    * password
    * displayname
    * dateofbirth
    * country
    * language

    Properties:
        url: /event/v2/public/namespaces/{namespace}/users/{userId}/edithistory

        method: GET

        tags: ["Event V2"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        page_size: (pageSize) OPTIONAL int in query

        start_date: (startDate) OPTIONAL str in query

        type_: (type) OPTIONAL str in query

    Responses:
        200: OK - ModelsEventResponseV2 (OK)

        400: Bad Request - (Bad Request)

        401: Unauthorized - (Unauthorized)

        403: Forbidden - (Forbidden)

        404: Not Found - (Not Found)

        500: Internal Server Error - (Internal Server Error)

        501: Not Implemented - (Not Implemented)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetPublicEditHistory.create(
        user_id=user_id,
        end_date=end_date,
        offset=offset,
        page_size=page_size,
        start_date=start_date,
        type_=type_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetPublicEditHistory)
async def get_public_edit_history_async(
    user_id: str,
    end_date: Optional[str] = None,
    offset: Optional[int] = None,
    page_size: Optional[int] = None,
    start_date: Optional[str] = None,
    type_: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get a user edit history based on the provided type (GetPublicEditHistory)

    Available Type:
    * email
    * password
    * displayname
    * dateofbirth
    * country
    * language

    Properties:
        url: /event/v2/public/namespaces/{namespace}/users/{userId}/edithistory

        method: GET

        tags: ["Event V2"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        page_size: (pageSize) OPTIONAL int in query

        start_date: (startDate) OPTIONAL str in query

        type_: (type) OPTIONAL str in query

    Responses:
        200: OK - ModelsEventResponseV2 (OK)

        400: Bad Request - (Bad Request)

        401: Unauthorized - (Unauthorized)

        403: Forbidden - (Forbidden)

        404: Not Found - (Not Found)

        500: Internal Server Error - (Internal Server Error)

        501: Not Implemented - (Not Implemented)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetPublicEditHistory.create(
        user_id=user_id,
        end_date=end_date,
        offset=offset,
        page_size=page_size,
        start_date=start_date,
        type_=type_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetUserEventsV2Public)
def get_user_events_v2_public(
    user_id: str,
    end_date: Optional[str] = None,
    event_name: Optional[str] = None,
    offset: Optional[int] = None,
    page_size: Optional[int] = None,
    start_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get events from a specific user (GetUserEventsV2Public)

    Requires valid user access token

    Properties:
        url: /event/v2/public/namespaces/{namespace}/users/{userId}/event

        method: GET

        tags: ["Event V2"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        event_name: (eventName) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        page_size: (pageSize) OPTIONAL int in query

        start_date: (startDate) OPTIONAL str in query

    Responses:
        200: OK - ModelsEventResponseV2 (OK)

        400: Bad Request - (Bad Request)

        401: Unauthorized - (Unauthorized)

        403: Forbidden - (Forbidden)

        404: Not Found - (Not Found)

        500: Internal Server Error - (Internal Server Error)

        501: Not Implemented - (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserEventsV2Public.create(
        user_id=user_id,
        end_date=end_date,
        event_name=event_name,
        offset=offset,
        page_size=page_size,
        start_date=start_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetUserEventsV2Public)
async def get_user_events_v2_public_async(
    user_id: str,
    end_date: Optional[str] = None,
    event_name: Optional[str] = None,
    offset: Optional[int] = None,
    page_size: Optional[int] = None,
    start_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get events from a specific user (GetUserEventsV2Public)

    Requires valid user access token

    Properties:
        url: /event/v2/public/namespaces/{namespace}/users/{userId}/event

        method: GET

        tags: ["Event V2"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        event_name: (eventName) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        page_size: (pageSize) OPTIONAL int in query

        start_date: (startDate) OPTIONAL str in query

    Responses:
        200: OK - ModelsEventResponseV2 (OK)

        400: Bad Request - (Bad Request)

        401: Unauthorized - (Unauthorized)

        403: Forbidden - (Forbidden)

        404: Not Found - (Not Found)

        500: Internal Server Error - (Internal Server Error)

        501: Not Implemented - (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserEventsV2Public.create(
        user_id=user_id,
        end_date=end_date,
        event_name=event_name,
        offset=offset,
        page_size=page_size,
        start_date=start_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryEventStreamHandler)
def query_event_stream_handler(
    body: ModelsGenericQueryPayload,
    end_date: Optional[str] = None,
    offset: Optional[int] = None,
    page_size: Optional[int] = None,
    start_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """A generic query to get a set of events based on the provided filters (QueryEventStreamHandler)

    This endpoint is using POST which is somewhat unfamiliar,
    but it's logical that we have to send/post a filter (search term) in order to get the data.
    This endpoint will not return anything if you give it an empty filters in the request body.

    Properties:
        url: /event/v2/admin/namespaces/{namespace}/query

        method: POST

        tags: ["Event V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGenericQueryPayload in body

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        page_size: (pageSize) OPTIONAL int in query

        start_date: (startDate) OPTIONAL str in query

    Responses:
        200: OK - ModelsEventResponseV2 (OK)

        400: Bad Request - (Bad Request)

        401: Unauthorized - (Unauthorized)

        403: Forbidden - (Forbidden)

        404: Not Found - (Not Found)

        500: Internal Server Error - (Internal Server Error)

        501: Not Implemented - (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryEventStreamHandler.create(
        body=body,
        end_date=end_date,
        offset=offset,
        page_size=page_size,
        start_date=start_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryEventStreamHandler)
async def query_event_stream_handler_async(
    body: ModelsGenericQueryPayload,
    end_date: Optional[str] = None,
    offset: Optional[int] = None,
    page_size: Optional[int] = None,
    start_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """A generic query to get a set of events based on the provided filters (QueryEventStreamHandler)

    This endpoint is using POST which is somewhat unfamiliar,
    but it's logical that we have to send/post a filter (search term) in order to get the data.
    This endpoint will not return anything if you give it an empty filters in the request body.

    Properties:
        url: /event/v2/admin/namespaces/{namespace}/query

        method: POST

        tags: ["Event V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGenericQueryPayload in body

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        page_size: (pageSize) OPTIONAL int in query

        start_date: (startDate) OPTIONAL str in query

    Responses:
        200: OK - ModelsEventResponseV2 (OK)

        400: Bad Request - (Bad Request)

        401: Unauthorized - (Unauthorized)

        403: Forbidden - (Forbidden)

        404: Not Found - (Not Found)

        500: Internal Server Error - (Internal Server Error)

        501: Not Implemented - (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryEventStreamHandler.create(
        body=body,
        end_date=end_date,
        offset=offset,
        page_size=page_size,
        start_date=start_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Dsm Controller Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsImageReplication(Model):
    """Models image replication (models.ImageReplication)

    Properties:
        failure_code: (failure_code) REQUIRED str

        region: (region) REQUIRED str

        status: (status) REQUIRED str

        uri: (uri) REQUIRED str
    """

    # region fields

    failure_code: str  # REQUIRED
    region: str  # REQUIRED
    status: str  # REQUIRED
    uri: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_failure_code(self, value: str) -> ModelsImageReplication:
        self.failure_code = value
        return self

    def with_region(self, value: str) -> ModelsImageReplication:
        self.region = value
        return self

    def with_status(self, value: str) -> ModelsImageReplication:
        self.status = value
        return self

    def with_uri(self, value: str) -> ModelsImageReplication:
        self.uri = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "failure_code"):
            result["failure_code"] = str(self.failure_code)
        elif include_empty:
            result["failure_code"] = ""
        if hasattr(self, "region"):
            result["region"] = str(self.region)
        elif include_empty:
            result["region"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = ""
        if hasattr(self, "uri"):
            result["uri"] = str(self.uri)
        elif include_empty:
            result["uri"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, failure_code: str, region: str, status: str, uri: str, **kwargs
    ) -> ModelsImageReplication:
        instance = cls()
        instance.failure_code = failure_code
        instance.region = region
        instance.status = status
        instance.uri = uri
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsImageReplication:
        instance = cls()
        if not dict_:
            return instance
        if "failure_code" in dict_ and dict_["failure_code"] is not None:
            instance.failure_code = str(dict_["failure_code"])
        elif include_empty:
            instance.failure_code = ""
        if "region" in dict_ and dict_["region"] is not None:
            instance.region = str(dict_["region"])
        elif include_empty:
            instance.region = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = ""
        if "uri" in dict_ and dict_["uri"] is not None:
            instance.uri = str(dict_["uri"])
        elif include_empty:
            instance.uri = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsImageReplication]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsImageReplication]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsImageReplication,
        List[ModelsImageReplication],
        Dict[Any, ModelsImageReplication],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "failure_code": "failure_code",
            "region": "region",
            "status": "status",
            "uri": "uri",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "failure_code": True,
            "region": True,
            "status": True,
            "uri": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "4.52.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .fulfill_item import FulfillItem
from .fulfill_rewards import FulfillRewards
from .fulfill_rewards_v2 import FulfillRewardsV2
from .pre_check_fulfill_item import PreCheckFulfillItem
from .public_redeem_code import PublicRedeemCode
from .query_fulfillment_histories import QueryFulfillmentHistories
from .query_fulfillment_histories import (
    StatusEnum as QueryFulfillmentHistoriesStatusEnum,
)
from .redeem_code import RedeemCode



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Ds Artifact Manager

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.dsartifact.models import LogAppMessageDeclaration
from ..api.dsartifact.models import ModelsAllQueueResult
from ..api.dsartifact.models import ModelsArtifactFileStatus
from ..api.dsartifact.models import ModelsListAllQueueResponse
from ..api.dsartifact.models import ModelsListNodesIPAddress
from ..api.dsartifact.models import ModelsListQueueResponse
from ..api.dsartifact.models import ModelsListTerminatedServersResponse
from ..api.dsartifact.models import ModelsMatchResult
from ..api.dsartifact.models import ModelsNotifPayloadServerStatusChange
from ..api.dsartifact.models import ModelsPagingCursor
from ..api.dsartifact.models import ModelsQueue
from ..api.dsartifact.models import ModelsQueueResult
from ..api.dsartifact.models import ModelsRequestMatchMember
from ..api.dsartifact.models import ModelsRequestMatchParty
from ..api.dsartifact.models import ModelsRequestMatchingAlly
from ..api.dsartifact.models import ModelsServer
from ..api.dsartifact.models import ModelsStatusHistory
from ..api.dsartifact.models import ResponseError


def create_log_app_message_declaration_example() -> LogAppMessageDeclaration:
    instance = LogAppMessageDeclaration()
    instance.attributes = [randomize()]
    instance.code = randomize()
    instance.code_name = randomize()
    instance.section = randomize()
    instance.service = randomize()
    instance.text = randomize()
    return instance


def create_models_all_queue_result_example() -> ModelsAllQueueResult:
    instance = ModelsAllQueueResult()
    instance.allocation_id = randomize()
    instance.created_at = randomize("date")
    instance.failed = randomize("bool")
    instance.failed_reason = randomize()
    instance.node_ip = randomize()
    instance.pod_name = randomize()
    instance.uploading = randomize("bool")
    return instance


def create_models_artifact_file_status_example() -> ModelsArtifactFileStatus:
    instance = ModelsArtifactFileStatus()
    instance.artifact_existence = randomize("bool")
    instance.artifact_status = randomize()
    return instance


def create_models_list_all_queue_response_example() -> ModelsListAllQueueResponse:
    instance = ModelsListAllQueueResponse()
    instance.data = [create_models_all_queue_result_example()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_list_nodes_ip_address_example() -> ModelsListNodesIPAddress:
    instance = ModelsListNodesIPAddress()
    instance.ip_addresses = [randomize()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_list_queue_response_example() -> ModelsListQueueResponse:
    instance = ModelsListQueueResponse()
    instance.data = [create_models_queue_result_example()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_list_terminated_servers_response_example() -> (
    ModelsListTerminatedServersResponse
):
    instance = ModelsListTerminatedServersResponse()
    instance.data = [create_models_notif_payload_server_status_change_example()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_match_result_example() -> ModelsMatchResult:
    instance = ModelsMatchResult()
    instance.game_mode = randomize()
    instance.matching_allies = [create_models_request_matching_ally_example()]
    instance.namespace = randomize("slug")
    instance.session_id = randomize("uid")
    return instance


def create_models_notif_payload_server_status_change_example() -> (
    ModelsNotifPayloadServerStatusChange
):
    instance = ModelsNotifPayloadServerStatusChange()
    instance.match = create_models_match_result_example()
    instance.server = create_models_server_example()
    instance.source = randomize()
    return instance


def create_models_paging_cursor_example() -> ModelsPagingCursor:
    instance = ModelsPagingCursor()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_models_queue_example() -> ModelsQueue:
    instance = ModelsQueue()
    instance.allocation_id = randomize()
    instance.created_at = randomize("date")
    instance.failed = randomize("bool")
    instance.failed_reason = randomize()
    instance.namespace = randomize("slug")
    instance.node_ip = randomize()
    instance.pod_name = randomize()
    instance.uploading = randomize("bool")
    return instance


def create_models_queue_result_example() -> ModelsQueueResult:
    instance = ModelsQueueResult()
    instance.allocation_id = randomize()
    instance.created_at = randomize("date")
    instance.pod_name = randomize()
    return instance


def create_models_request_match_member_example() -> ModelsRequestMatchMember:
    instance = ModelsRequestMatchMember()
    instance.user_id = randomize("uid")
    return instance


def create_models_request_match_party_example() -> ModelsRequestMatchParty:
    instance = ModelsRequestMatchParty()
    instance.party_attributes = {randomize(): randomize()}
    instance.party_id = randomize("uid")
    instance.party_members = [create_models_request_match_member_example()]
    return instance


def create_models_request_matching_ally_example() -> ModelsRequestMatchingAlly:
    instance = ModelsRequestMatchingAlly()
    instance.matching_parties = [create_models_request_match_party_example()]
    return instance


def create_models_server_example() -> ModelsServer:
    instance = ModelsServer()
    instance.allocation_id = randomize()
    instance.alternate_ips = [randomize()]
    instance.artifact_path = randomize()
    instance.cpu_limit = randomize("int", min_val=1, max_val=1000)
    instance.deployment = randomize()
    instance.game_version = randomize("version")
    instance.image_version = randomize()
    instance.ip = randomize()
    instance.is_core_dump_enabled = randomize("bool")
    instance.last_update = randomize("date")
    instance.mem_limit = randomize("int", min_val=1, max_val=1000)
    instance.namespace = randomize("slug")
    instance.params = randomize()
    instance.pod_name = randomize()
    instance.port = randomize("int", min_val=1, max_val=1000)
    instance.ports = {}
    instance.provider = randomize()
    instance.region = randomize()
    instance.session_id = randomize("uid")
    instance.status = randomize()
    instance.status_history = [create_models_status_history_example()]
    return instance


def create_models_status_history_example() -> ModelsStatusHistory:
    instance = ModelsStatusHistory()
    instance.status = randomize()
    instance.time_stamp = randomize("date")
    return instance


def create_response_error_example() -> ResponseError:
    instance = ResponseError()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Leaderboard Service."""

__version__ = "2.29.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_archived_lead_191726 import (
    AdminGetArchivedLeaderboardRankingDataV1Handler,
)
from .create_archived_leaderb_5492e4 import (
    CreateArchivedLeaderboardRankingDataV1Handler,
)
from .delete_user_ranking_admin_v1 import DeleteUserRankingAdminV1
from .delete_user_ranking_by__ed6de1 import DeleteUserRankingByLeaderboardCodeAdminV1
from .delete_user_ranking_public_v1 import DeleteUserRankingPublicV1
from .delete_user_rankings_admin_v1 import DeleteUserRankingsAdminV1
from .get_all_time_leaderboar_d0fb4b import GetAllTimeLeaderboardRankingAdminV1
from .get_all_time_leaderboar_358b23 import GetAllTimeLeaderboardRankingPublicV1
from .get_all_time_leaderboar_9cbcdd import GetAllTimeLeaderboardRankingPublicV2
from .get_archived_leaderboar_c023ea import GetArchivedLeaderboardRankingDataV1Handler
from .get_current_month_leade_26486d import GetCurrentMonthLeaderboardRankingAdminV1
from .get_current_month_leade_4373db import GetCurrentMonthLeaderboardRankingPublicV1
from .get_current_season_lead_a79ffc import GetCurrentSeasonLeaderboardRankingAdminV1
from .get_current_season_lead_51d992 import GetCurrentSeasonLeaderboardRankingPublicV1
from .get_current_week_leader_bdd5ce import GetCurrentWeekLeaderboardRankingAdminV1
from .get_current_week_leader_07d571 import GetCurrentWeekLeaderboardRankingPublicV1
from .get_today_leaderboard_r_2eefd7 import GetTodayLeaderboardRankingAdminV1
from .get_today_leaderboard_r_51cbb5 import GetTodayLeaderboardRankingPublicV1
from .get_user_ranking_admin_v1 import GetUserRankingAdminV1
from .get_user_ranking_public_v1 import GetUserRankingPublicV1
from .update_user_point_admin_v1 import UpdateUserPointAdminV1



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ErrorEntity
from ..models import SteamAchievementUpdateRequest
from ..models import ValidationErrorEntity
from ..models import XblAchievementUpdateRequest
from ..models import XblUserAchievements

from ..operations.achievement_platform import GetXblUserAchievements
from ..operations.achievement_platform import UnlockSteamUserAchievement
from ..operations.achievement_platform import UpdateXblUserAchievement


@same_doc_as(GetXblUserAchievements)
def get_xbl_user_achievements(
    user_id: str,
    xbox_user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get xbox live user achievements. (getXblUserAchievements)

    This API is used to get xbox live user achievements(Only for test).

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/achievement/xbl

        method: GET

        tags: ["Achievement(Platform)"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        xbox_user_id: (xboxUserId) REQUIRED str in query

    Responses:
        200: OK - XblUserAchievements (OK)

        400: Bad Request - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetXblUserAchievements.create(
        user_id=user_id,
        xbox_user_id=xbox_user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetXblUserAchievements)
async def get_xbl_user_achievements_async(
    user_id: str,
    xbox_user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get xbox live user achievements. (getXblUserAchievements)

    This API is used to get xbox live user achievements(Only for test).

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/achievement/xbl

        method: GET

        tags: ["Achievement(Platform)"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        xbox_user_id: (xboxUserId) REQUIRED str in query

    Responses:
        200: OK - XblUserAchievements (OK)

        400: Bad Request - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetXblUserAchievements.create(
        user_id=user_id,
        xbox_user_id=xbox_user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UnlockSteamUserAchievement)
def unlock_steam_user_achievement(
    user_id: str,
    body: Optional[SteamAchievementUpdateRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Unlock steam achievement. (unlockSteamUserAchievement)

    This API is used to unlock steam achievement.

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/achievement/steam

        method: PUT

        tags: ["Achievement(Platform)"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL SteamAchievementUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ValidationErrorEntity (20002: validation error)

        404: Not Found - ErrorEntity (39244: Steam config does not exist | 39245: Steam app id does not exist)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UnlockSteamUserAchievement.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UnlockSteamUserAchievement)
async def unlock_steam_user_achievement_async(
    user_id: str,
    body: Optional[SteamAchievementUpdateRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Unlock steam achievement. (unlockSteamUserAchievement)

    This API is used to unlock steam achievement.

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/achievement/steam

        method: PUT

        tags: ["Achievement(Platform)"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL SteamAchievementUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ValidationErrorEntity (20002: validation error)

        404: Not Found - ErrorEntity (39244: Steam config does not exist | 39245: Steam app id does not exist)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UnlockSteamUserAchievement.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateXblUserAchievement)
def update_xbl_user_achievement(
    user_id: str,
    body: Optional[XblAchievementUpdateRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update xbox live achievements. (updateXblUserAchievement)

    This API is used to update xbox live achievements.

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/achievement/xbl

        method: PUT

        tags: ["Achievement(Platform)"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL XblAchievementUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateXblUserAchievement.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateXblUserAchievement)
async def update_xbl_user_achievement_async(
    user_id: str,
    body: Optional[XblAchievementUpdateRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update xbox live achievements. (updateXblUserAchievement)

    This API is used to update xbox live achievements.

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/achievement/xbl

        method: PUT

        tags: ["Achievement(Platform)"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL XblAchievementUpdateRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateXblUserAchievement.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApiDSHistoryList
from ..models import ApiFleetServerConnectionInfoResponse
from ..models import ApiFleetServerHistoryResponse
from ..models import ApiFleetServerInfoResponse
from ..models import ResponseErrorResponse

from ..operations.servers import FleetServerConnectionInfo
from ..operations.servers import FleetServerHistory
from ..operations.servers import FleetServerInfo
from ..operations.servers import ServerHistory


@same_doc_as(FleetServerConnectionInfo)
def fleet_server_connection_info(
    server_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get connection info for a dedicated server (FleetServerConnectionInfo)

    Required Permission: ADMIN:NAMESPACE:{namespace}:AMS:DS:LOGS [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:AMS:DS:LOGS [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/servers/{serverID}/connectioninfo

        method: GET

        tags: ["Servers"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        server_id: (serverID) REQUIRED str in path

    Responses:
        200: OK - ApiFleetServerConnectionInfoResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (dedicated server not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetServerConnectionInfo.create(
        server_id=server_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetServerConnectionInfo)
async def fleet_server_connection_info_async(
    server_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get connection info for a dedicated server (FleetServerConnectionInfo)

    Required Permission: ADMIN:NAMESPACE:{namespace}:AMS:DS:LOGS [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:AMS:DS:LOGS [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/servers/{serverID}/connectioninfo

        method: GET

        tags: ["Servers"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        server_id: (serverID) REQUIRED str in path

    Responses:
        200: OK - ApiFleetServerConnectionInfoResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (dedicated server not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetServerConnectionInfo.create(
        server_id=server_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(FleetServerHistory)
def fleet_server_history(
    fleet_id: str,
    count: Optional[int] = None,
    offset: Optional[int] = None,
    reason: Optional[str] = None,
    region: Optional[str] = None,
    server_id: Optional[str] = None,
    sort_direction: Optional[str] = None,
    status: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get history records of a dedicated server in a fleet (FleetServerHistory)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}/servers/history

        method: GET

        tags: ["Servers"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        count: (count) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        reason: (reason) OPTIONAL str in query

        region: (region) OPTIONAL str in query

        server_id: (serverId) OPTIONAL str in query

        sort_direction: (sortDirection) OPTIONAL str in query

        status: (status) OPTIONAL str in query

    Responses:
        200: OK - ApiDSHistoryList (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetServerHistory.create(
        fleet_id=fleet_id,
        count=count,
        offset=offset,
        reason=reason,
        region=region,
        server_id=server_id,
        sort_direction=sort_direction,
        status=status,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetServerHistory)
async def fleet_server_history_async(
    fleet_id: str,
    count: Optional[int] = None,
    offset: Optional[int] = None,
    reason: Optional[str] = None,
    region: Optional[str] = None,
    server_id: Optional[str] = None,
    sort_direction: Optional[str] = None,
    status: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get history records of a dedicated server in a fleet (FleetServerHistory)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}/servers/history

        method: GET

        tags: ["Servers"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        count: (count) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        reason: (reason) OPTIONAL str in query

        region: (region) OPTIONAL str in query

        server_id: (serverId) OPTIONAL str in query

        sort_direction: (sortDirection) OPTIONAL str in query

        status: (status) OPTIONAL str in query

    Responses:
        200: OK - ApiDSHistoryList (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetServerHistory.create(
        fleet_id=fleet_id,
        count=count,
        offset=offset,
        reason=reason,
        region=region,
        server_id=server_id,
        sort_direction=sort_direction,
        status=status,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(FleetServerInfo)
def fleet_server_info(
    server_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get information about a dedicated server (FleetServerInfo)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/servers/{serverID}

        method: GET

        tags: ["Servers"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        server_id: (serverID) REQUIRED str in path

    Responses:
        200: OK - ApiFleetServerInfoResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (dedicated server not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetServerInfo.create(
        server_id=server_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetServerInfo)
async def fleet_server_info_async(
    server_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get information about a dedicated server (FleetServerInfo)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/servers/{serverID}

        method: GET

        tags: ["Servers"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        server_id: (serverID) REQUIRED str in path

    Responses:
        200: OK - ApiFleetServerInfoResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (dedicated server not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetServerInfo.create(
        server_id=server_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ServerHistory)
def server_history(
    server_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get history records of a dedicated server (ServerHistory)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/servers/{serverID}/history

        method: GET

        tags: ["Servers"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        server_id: (serverID) REQUIRED str in path

    Responses:
        200: OK - ApiFleetServerHistoryResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ServerHistory.create(
        server_id=server_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ServerHistory)
async def server_history_async(
    server_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get history records of a dedicated server (ServerHistory)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/servers/{serverID}/history

        method: GET

        tags: ["Servers"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        server_id: (serverID) REQUIRED str in path

    Responses:
        200: OK - ApiFleetServerHistoryResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ServerHistory.create(
        server_id=server_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "7.16.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .authentication_with_pla_4d2d24 import AuthenticationWithPlatformLinkV3
from .generate_token_by_new_h_af6555 import GenerateTokenByNewHeadlessAccountV3
from .get_country_location_v3 import GetCountryLocationV3
from .logout import Logout
from .platform_authentication_v3 import PlatformAuthenticationV3
from .platform_token_refresh_v3 import PlatformTokenRefreshV3
from .request_one_time_linkin_a9550a import RequestOneTimeLinkingCodeV3
from .request_target_token_re_2a2d5b import RequestTargetTokenResponseV3
from .request_token_by_one_ti_ace4f2 import RequestTokenByOneTimeLinkCodeResponseV3
from .request_token_exchange_code_v3 import RequestTokenExchangeCodeV3
from .request_token_exchange_code_v3 import (
    CodeChallengeMethodEnum as RequestTokenExchangeCodeV3CodeChallengeMethodEnum,
)
from .user_authentication_v3 import UserAuthenticationV3
from .validate_one_time_linki_84d856 import ValidateOneTimeLinkingCodeV3



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.

import urllib.parse

from typing import Any, Dict, List, Optional, Union

from ._http_status_codes import HTTP_STATUS_CODES
from ._model import Model


class HttpResponse(Model):
    """HTTP Error

    Properties:

        code: (code) OPTIONAL int

        content_type: (content_type) OPTIONAL str

        content: (content) OPTIONAL Any
    """

    code: int
    content_type: str
    content: Any

    def __str__(self):
        return f"[{self.code}] {self.content_type}: {str(self.content)}"

    def is_error(self) -> bool:
        return self.content_type == "error"

    def is_no_content(self) -> bool:
        return self.content_type == "no_content"

    def get_query_params(self) -> dict:
        if self.content_type == "location":
            return urllib.parse.parse_qs(urllib.parse.urlparse(self.content).query)
        return {}

    @classmethod
    def create(cls, code: int, message: str):
        instance = cls()
        instance.code = code
        instance.content_type = "message"
        instance.content = message
        return instance

    @classmethod
    def create_redirect(cls, code: int, location: str):
        instance = cls()
        instance.code = code
        instance.content_type = "location"
        instance.content = location
        return instance

    @classmethod
    def create_error(cls, code: int, error: str):
        instance = cls()
        instance.code = code
        instance.content_type = "error"
        instance.content = error
        return instance

    @classmethod
    def create_connection_error(cls):
        instance = cls()
        instance.code = 0
        instance.content_type = "error"
        instance.content = "Connection Error"
        return instance

    @classmethod
    def create_undocumented_response(cls, code: int, content_type: str, content: Any):
        if code not in HTTP_STATUS_CODES:
            return None
        if code == 200 and not content:
            content_type = "no_content"
            content = None
        elif code == 204:
            content_type = "no_content"
            content = None
        elif 400 <= code <= 599:
            content_type = "error"
        instance = cls()
        instance.code = code
        instance.content_type = content_type
        instance.content = content
        return instance

    @classmethod
    def create_unexpected_content_type_error(
        cls,
        actual: Optional[str] = None,
        expected: Optional[Union[str, List[str]]] = None,
        error: Optional[str] = None,
    ):
        content = "Unexpected Content-Type Error"
        if actual is not None and expected is not None:
            content += f" (actual: {actual} expected one in: {expected})"
        elif actual is not None:
            content += f" (actual: {actual})"
        elif expected is not None:
            content += f" (expected: {expected})"
        if error:
            content += f"\n{error}"
        instance = cls()
        instance.code = -1
        instance.content_type = "error"
        instance.content = content
        return instance

    @classmethod
    def create_unhandled_error(cls):
        instance = cls()
        instance.code = -1
        instance.content_type = "error"
        instance.content = "Unhandled Error"
        return instance

    @classmethod
    def create_sdk_not_initialized_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "SDK not initialized."
        return instance

    @classmethod
    def create_base_url_not_set_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "Base URL not set."
        return instance

    @classmethod
    def create_client_not_registered_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "Client not registered."
        return instance

    @classmethod
    def create_token_not_found_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "Token not found."
        return instance

    @classmethod
    def create_token_invalid_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "Token invalid."
        return instance

    @classmethod
    def create_config_repo_not_found_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "Config repository not found."
        return instance

    @classmethod
    def create_token_repo_not_found_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "Token repository not found."
        return instance

    @classmethod
    def create_http_client_not_found_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "HTTP client not found."
        return instance

    @classmethod
    def create_failed_to_resolve_security_error(cls, detail: Optional[str] = None):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "Failed to resolve security."
        if detail:
            instance.content += f"\n{detail}"
        return instance

    @classmethod
    def create_failed_to_remove_token_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "Failed to remove token."
        return instance

    @classmethod
    def create_failed_to_set_token_error(cls):
        instance = cls()
        instance.code = 400
        instance.content_type = "error"
        instance.content = "Failed to set token."
        return instance

    @classmethod
    def try_create_undocumented_response(cls, code: int, content: Any):
        if code not in HTTP_STATUS_CODES:
            return False, None
        content_type = "error"
        if code == 204:
            content_type = "no_content"
            content = None
        instance = cls()
        instance.code = code
        instance.content_type = content_type
        instance.content = content
        return True, instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "code": "code",
            "content_type": "content_type",
            "content": "content",
        }



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import CreateBasePolicyRequest
from ..models import CreateBasePolicyResponse
from ..models import ErrorEntity
from ..models import RetrieveBasePolicyResponse
from ..models import RetrievePolicyResponse
from ..models import RetrievePolicyTypeResponse
from ..models import UpdateBasePolicyRequest
from ..models import UpdateBasePolicyResponse
from ..models import ValidationErrorEntity

from ..operations.base_legal_policies import CreatePolicy
from ..operations.base_legal_policies import PartialUpdatePolicy
from ..operations.base_legal_policies import RetrieveAllLegalPolicies
from ..operations.base_legal_policies import RetrieveAllPolicyTypes
from ..operations.base_legal_policies import RetrievePolicyCountry
from ..operations.base_legal_policies import RetrieveSinglePolicy


@same_doc_as(CreatePolicy)
def create_policy(
    body: Optional[CreateBasePolicyRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a Base Legal Policy (createPolicy)

    Create a legal policy.

    Properties:
        url: /agreement/admin/base-policies

        method: POST

        tags: ["Base Legal Policies"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL CreateBasePolicyRequest in body

    Responses:
        201: Created - CreateBasePolicyResponse (successful operation)

        400: Bad Request - ErrorEntity (40038: errors.net.accelbyte.platform.legal.invalid_affected_client_id | 40026: errors.net.accelbyte.platform.legal.not_allow_create_studio_policy)

        404: Not Found - ErrorEntity (40030: errors.net.accelbyte.platform.legal.policy_type_not_exist)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    request = CreatePolicy.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreatePolicy)
async def create_policy_async(
    body: Optional[CreateBasePolicyRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a Base Legal Policy (createPolicy)

    Create a legal policy.

    Properties:
        url: /agreement/admin/base-policies

        method: POST

        tags: ["Base Legal Policies"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL CreateBasePolicyRequest in body

    Responses:
        201: Created - CreateBasePolicyResponse (successful operation)

        400: Bad Request - ErrorEntity (40038: errors.net.accelbyte.platform.legal.invalid_affected_client_id | 40026: errors.net.accelbyte.platform.legal.not_allow_create_studio_policy)

        404: Not Found - ErrorEntity (40030: errors.net.accelbyte.platform.legal.policy_type_not_exist)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    request = CreatePolicy.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PartialUpdatePolicy)
def partial_update_policy(
    base_policy_id: str,
    body: Optional[UpdateBasePolicyRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Base Legal Policy (partialUpdatePolicy)

    Update an existing base policy.

    Properties:
        url: /agreement/admin/base-policies/{basePolicyId}

        method: PATCH

        tags: ["Base Legal Policies"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UpdateBasePolicyRequest in body

        base_policy_id: (basePolicyId) REQUIRED str in path

    Responses:
        200: OK - UpdateBasePolicyResponse (successful operation)

        400: Bad Request - ErrorEntity (40032: errors.net.accelbyte.platform.legal.invalid_base_policy | 40038: errors.net.accelbyte.platform.legal.invalid_affected_client_id)

        404: Not Found - ErrorEntity (40030: errors.net.accelbyte.platform.legal.policy_type_not_exist)
    """
    request = PartialUpdatePolicy.create(
        base_policy_id=base_policy_id,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PartialUpdatePolicy)
async def partial_update_policy_async(
    base_policy_id: str,
    body: Optional[UpdateBasePolicyRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Base Legal Policy (partialUpdatePolicy)

    Update an existing base policy.

    Properties:
        url: /agreement/admin/base-policies/{basePolicyId}

        method: PATCH

        tags: ["Base Legal Policies"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UpdateBasePolicyRequest in body

        base_policy_id: (basePolicyId) REQUIRED str in path

    Responses:
        200: OK - UpdateBasePolicyResponse (successful operation)

        400: Bad Request - ErrorEntity (40032: errors.net.accelbyte.platform.legal.invalid_base_policy | 40038: errors.net.accelbyte.platform.legal.invalid_affected_client_id)

        404: Not Found - ErrorEntity (40030: errors.net.accelbyte.platform.legal.policy_type_not_exist)
    """
    request = PartialUpdatePolicy.create(
        base_policy_id=base_policy_id,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveAllLegalPolicies)
def retrieve_all_legal_policies(
    visible_only: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve All Base Legal Policy (retrieveAllLegalPolicies)

    Retrieve all base policies.

    Properties:
        url: /agreement/admin/base-policies

        method: GET

        tags: ["Base Legal Policies"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        visible_only: (visibleOnly) OPTIONAL bool in query

    Responses:
        200: OK - List[RetrieveBasePolicyResponse] (successful operation)
    """
    request = RetrieveAllLegalPolicies.create(
        visible_only=visible_only,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveAllLegalPolicies)
async def retrieve_all_legal_policies_async(
    visible_only: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve All Base Legal Policy (retrieveAllLegalPolicies)

    Retrieve all base policies.

    Properties:
        url: /agreement/admin/base-policies

        method: GET

        tags: ["Base Legal Policies"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        visible_only: (visibleOnly) OPTIONAL bool in query

    Responses:
        200: OK - List[RetrieveBasePolicyResponse] (successful operation)
    """
    request = RetrieveAllLegalPolicies.create(
        visible_only=visible_only,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveAllPolicyTypes)
def retrieve_all_policy_types(
    limit: int,
    offset: Optional[int] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve All Policy Type (retrieveAllPolicyTypes)

    Retrieve all supported policy types.

    Properties:
        url: /agreement/admin/policy-types

        method: GET

        tags: ["Base Legal Policies"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        offset: (offset) OPTIONAL int in query

        limit: (limit) REQUIRED int in query

    Responses:
        200: OK - List[RetrievePolicyTypeResponse] (successful operation)
    """
    request = RetrieveAllPolicyTypes.create(
        limit=limit,
        offset=offset,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveAllPolicyTypes)
async def retrieve_all_policy_types_async(
    limit: int,
    offset: Optional[int] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve All Policy Type (retrieveAllPolicyTypes)

    Retrieve all supported policy types.

    Properties:
        url: /agreement/admin/policy-types

        method: GET

        tags: ["Base Legal Policies"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        offset: (offset) OPTIONAL int in query

        limit: (limit) REQUIRED int in query

    Responses:
        200: OK - List[RetrievePolicyTypeResponse] (successful operation)
    """
    request = RetrieveAllPolicyTypes.create(
        limit=limit,
        offset=offset,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrievePolicyCountry)
def retrieve_policy_country(
    base_policy_id: str,
    country_code: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve a Base Legal Policy based on a Particular Country (retrievePolicyCountry)

    Retrieve a Base Legal Policy based on a Particular Country.

    Properties:
        url: /agreement/admin/base-policies/{basePolicyId}/countries/{countryCode}

        method: GET

        tags: ["Base Legal Policies"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        base_policy_id: (basePolicyId) REQUIRED str in path

        country_code: (countryCode) REQUIRED str in path

    Responses:
        200: OK - RetrievePolicyResponse (successful operation)

        404: Not Found - ErrorEntity (40041: errors.net.accelbyte.platform.legal.policy_not_found)
    """
    request = RetrievePolicyCountry.create(
        base_policy_id=base_policy_id,
        country_code=country_code,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrievePolicyCountry)
async def retrieve_policy_country_async(
    base_policy_id: str,
    country_code: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve a Base Legal Policy based on a Particular Country (retrievePolicyCountry)

    Retrieve a Base Legal Policy based on a Particular Country.

    Properties:
        url: /agreement/admin/base-policies/{basePolicyId}/countries/{countryCode}

        method: GET

        tags: ["Base Legal Policies"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        base_policy_id: (basePolicyId) REQUIRED str in path

        country_code: (countryCode) REQUIRED str in path

    Responses:
        200: OK - RetrievePolicyResponse (successful operation)

        404: Not Found - ErrorEntity (40041: errors.net.accelbyte.platform.legal.policy_not_found)
    """
    request = RetrievePolicyCountry.create(
        base_policy_id=base_policy_id,
        country_code=country_code,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveSinglePolicy)
def retrieve_single_policy(
    base_policy_id: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Retrieve a Base Legal Policy (retrieveSinglePolicy)

    Retrieve a base policy.

    Properties:
        url: /agreement/admin/base-policies/{basePolicyId}

        method: GET

        tags: ["Base Legal Policies"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        base_policy_id: (basePolicyId) REQUIRED str in path

    Responses:
        200: OK - RetrieveBasePolicyResponse (successful operation)

        404: Not Found - ErrorEntity (40031: errors.net.accelbyte.platform.legal.base_policy_not_found)
    """
    request = RetrieveSinglePolicy.create(
        base_policy_id=base_policy_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveSinglePolicy)
async def retrieve_single_policy_async(
    base_policy_id: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Retrieve a Base Legal Policy (retrieveSinglePolicy)

    Retrieve a base policy.

    Properties:
        url: /agreement/admin/base-policies/{basePolicyId}

        method: GET

        tags: ["Base Legal Policies"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        base_policy_id: (basePolicyId) REQUIRED str in path

    Responses:
        200: OK - RetrieveBasePolicyResponse (successful operation)

        404: Not Found - ErrorEntity (40031: errors.net.accelbyte.platform.legal.base_policy_not_found)
    """
    request = RetrieveSinglePolicy.create(
        base_policy_id=base_policy_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Achievement Service."""

__version__ = "2.22.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# achievements
from .wrappers import admin_create_new_achievement
from .wrappers import admin_create_new_achievement_async
from .wrappers import admin_delete_achievement
from .wrappers import admin_delete_achievement_async
from .wrappers import admin_get_achievement
from .wrappers import admin_get_achievement_async
from .wrappers import admin_list_achievements
from .wrappers import admin_list_achievements_async
from .wrappers import admin_update_achievement
from .wrappers import admin_update_achievement_async
from .wrappers import admin_update_achievement_list_order
from .wrappers import admin_update_achievement_list_order_async
from .wrappers import export_achievements
from .wrappers import export_achievements_async
from .wrappers import import_achievements
from .wrappers import import_achievements_async
from .wrappers import public_get_achievement
from .wrappers import public_get_achievement_async
from .wrappers import public_list_achievements
from .wrappers import public_list_achievements_async

# anonymization
from .wrappers import admin_anonymize_user_achievement
from .wrappers import admin_anonymize_user_achievement_async

# global_achievements
from .wrappers import admin_list_global_achievement_contributors
from .wrappers import admin_list_global_achievement_contributors_async
from .wrappers import admin_list_global_achievements
from .wrappers import admin_list_global_achievements_async
from .wrappers import admin_list_user_contributions
from .wrappers import admin_list_user_contributions_async
from .wrappers import claim_global_achievement_reward
from .wrappers import claim_global_achievement_reward_async
from .wrappers import list_global_achievement_contributors
from .wrappers import list_global_achievement_contributors_async
from .wrappers import list_user_contributions
from .wrappers import list_user_contributions_async
from .wrappers import public_list_global_achievements
from .wrappers import public_list_global_achievements_async
from .wrappers import reset_global_achievement
from .wrappers import reset_global_achievement_async

# platform_achievement
from .wrappers import bulk_create_psn_event
from .wrappers import bulk_create_psn_event_async

# tags
from .wrappers import admin_list_tags
from .wrappers import admin_list_tags_async
from .wrappers import public_list_tags
from .wrappers import public_list_tags_async

# user_achievements
from .wrappers import admin_list_user_achievements
from .wrappers import admin_list_user_achievements_async
from .wrappers import admin_reset_achievement
from .wrappers import admin_reset_achievement_async
from .wrappers import admin_unlock_achievement
from .wrappers import admin_unlock_achievement_async
from .wrappers import public_list_user_achievements
from .wrappers import public_list_user_achievements_async
from .wrappers import public_unlock_achievement
from .wrappers import public_unlock_achievement_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsGetHiddenUserResponse
from ..models import ModelsGetUserVisibilityResponse
from ..models import ModelsSetUserVisibilityRequest
from ..models import ResponseErrorResponse

from ..operations.user_visibility import GetHiddenUsersV2
from ..operations.user_visibility import GetUserVisibilityStatusV2
from ..operations.user_visibility import SetUserLeaderboardVisibilityStatusV2
from ..operations.user_visibility import SetUserVisibilityStatusV2


@same_doc_as(GetHiddenUsersV2)
def get_hidden_users_v2(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get hidden users on a leaderboard (GetHiddenUsersV2)

    Return hidden users on a leaderboard

    Properties:
        url: /leaderboard/v2/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/hidden

        method: GET

        tags: ["UserVisibility"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetHiddenUserResponse (Hidden user retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 71130: leaderboard config not found)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetHiddenUsersV2.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetHiddenUsersV2)
async def get_hidden_users_v2_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get hidden users on a leaderboard (GetHiddenUsersV2)

    Return hidden users on a leaderboard

    Properties:
        url: /leaderboard/v2/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/hidden

        method: GET

        tags: ["UserVisibility"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetHiddenUserResponse (Hidden user retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 71130: leaderboard config not found)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetHiddenUsersV2.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetUserVisibilityStatusV2)
def get_user_visibility_status_v2(
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user visibility status (GetUserVisibilityStatusV2)

    User with false visibility status will have hidden attribute set to true on it's leaderboard entry

    Properties:
        url: /leaderboard/v2/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}/visibility

        method: GET

        tags: ["UserVisibility"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetUserVisibilityResponse (User visibility retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserVisibilityStatusV2.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetUserVisibilityStatusV2)
async def get_user_visibility_status_v2_async(
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user visibility status (GetUserVisibilityStatusV2)

    User with false visibility status will have hidden attribute set to true on it's leaderboard entry

    Properties:
        url: /leaderboard/v2/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}/visibility

        method: GET

        tags: ["UserVisibility"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetUserVisibilityResponse (User visibility retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserVisibilityStatusV2.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SetUserLeaderboardVisibilityStatusV2)
def set_user_leaderboard_visibility_status_v2(
    body: ModelsSetUserVisibilityRequest,
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set user visibility status on a specific leaderboard code (SetUserLeaderboardVisibilityStatusV2)

    User with false visibility status will have hidden attribute set to true on it's leaderboard entry

    Properties:
        url: /leaderboard/v2/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}/visibility

        method: PUT

        tags: ["UserVisibility"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSetUserVisibilityRequest in body

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetUserVisibilityResponse (User visibility status updated)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 71130: leaderboard config not found | 20019: unable to parse request body)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SetUserLeaderboardVisibilityStatusV2.create(
        body=body,
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SetUserLeaderboardVisibilityStatusV2)
async def set_user_leaderboard_visibility_status_v2_async(
    body: ModelsSetUserVisibilityRequest,
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set user visibility status on a specific leaderboard code (SetUserLeaderboardVisibilityStatusV2)

    User with false visibility status will have hidden attribute set to true on it's leaderboard entry

    Properties:
        url: /leaderboard/v2/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}/visibility

        method: PUT

        tags: ["UserVisibility"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSetUserVisibilityRequest in body

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetUserVisibilityResponse (User visibility status updated)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 71130: leaderboard config not found | 20019: unable to parse request body)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SetUserLeaderboardVisibilityStatusV2.create(
        body=body,
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SetUserVisibilityStatusV2)
def set_user_visibility_status_v2(
    body: ModelsSetUserVisibilityRequest,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set user visibility status on a all current leaderboard (SetUserVisibilityStatusV2)

    User with false visibility status will have hidden attribute set to true on it's leaderboard entry

    Properties:
        url: /leaderboard/v2/admin/namespaces/{namespace}/users/{userId}/visibility

        method: PUT

        tags: ["UserVisibility"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSetUserVisibilityRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetUserVisibilityResponse (User visibility status updated)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SetUserVisibilityStatusV2.create(
        body=body,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SetUserVisibilityStatusV2)
async def set_user_visibility_status_v2_async(
    body: ModelsSetUserVisibilityRequest,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set user visibility status on a all current leaderboard (SetUserVisibilityStatusV2)

    User with false visibility status will have hidden attribute set to true on it's leaderboard entry

    Properties:
        url: /leaderboard/v2/admin/namespaces/{namespace}/users/{userId}/visibility

        method: PUT

        tags: ["UserVisibility"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSetUserVisibilityRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetUserVisibilityResponse (User visibility status updated)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SetUserVisibilityStatusV2.create(
        body=body,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ds Artifact Manager."""

__version__ = "1.11.4"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .log_app_message_declaration import LogAppMessageDeclaration
from .models_all_queue_result import ModelsAllQueueResult
from .models_artifact_file_status import ModelsArtifactFileStatus
from .models_list_all_queue_response import ModelsListAllQueueResponse
from .models_list_nodes_ip_address import ModelsListNodesIPAddress
from .models_list_queue_response import ModelsListQueueResponse
from .models_list_terminated_servers_response import ModelsListTerminatedServersResponse
from .models_match_result import ModelsMatchResult
from .models_notif_payload_server_status_change import (
    ModelsNotifPayloadServerStatusChange,
)
from .models_paging_cursor import ModelsPagingCursor
from .models_queue import ModelsQueue
from .models_queue_result import ModelsQueueResult
from .models_request_match_member import ModelsRequestMatchMember
from .models_request_match_party import ModelsRequestMatchParty
from .models_request_matching_ally import ModelsRequestMatchingAlly
from .models_server import ModelsServer
from .models_status_history import ModelsStatusHistory
from .response_error import ResponseError



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Lobby Server."""

__version__ = "3.35.5"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .handlers_get_users_presence_response import HandlersGetUsersPresenceResponse
from .handlers_user_presence import HandlersUserPresence
from .log_app_message_declaration import LogAppMessageDeclaration
from .model_bulk_friends_request import ModelBulkFriendsRequest
from .model_bulk_friends_response import ModelBulkFriendsResponse
from .model_bulk_users_free_form_notification_request_v1 import (
    ModelBulkUsersFreeFormNotificationRequestV1,
)
from .model_create_template_request import ModelCreateTemplateRequest
from .model_create_topic_request import ModelCreateTopicRequest
from .model_create_topic_request_v1 import ModelCreateTopicRequestV1
from .model_free_form_notification_request import ModelFreeFormNotificationRequest
from .model_free_form_notification_request_v1 import ModelFreeFormNotificationRequestV1
from .model_friend_with_platform import ModelFriendWithPlatform
from .model_friendship_connection import ModelFriendshipConnection
from .model_friendship_connection_response import ModelFriendshipConnectionResponse
from .model_get_all_notification_template_slug_resp import (
    ModelGetAllNotificationTemplateSlugResp,
)
from .model_get_all_notification_topics_response import (
    ModelGetAllNotificationTopicsResponse,
)
from .model_get_friends_response import ModelGetFriendsResponse
from .model_get_user_friends_response import ModelGetUserFriendsResponse
from .model_get_user_incoming_friends_response import (
    ModelGetUserIncomingFriendsResponse,
)
from .model_get_user_outgoing_friends_response import (
    ModelGetUserOutgoingFriendsResponse,
)
from .model_global_configuration import ModelGlobalConfiguration
from .model_incoming_friends_with_time_data import ModelIncomingFriendsWithTimeData
from .model_list_bulk_user_platforms_response import ModelListBulkUserPlatformsResponse
from .model_load_incoming_friends_with_time_response import (
    ModelLoadIncomingFriendsWithTimeResponse,
)
from .model_load_outgoing_friends_with_time_response import (
    ModelLoadOutgoingFriendsWithTimeResponse,
)
from .model_localization import ModelLocalization
from .model_native_friend_request import ModelNativeFriendRequest
from .model_native_friend_sync_response import ModelNativeFriendSyncResponse
from .model_native_user_block_request import ModelNativeUserBlockRequest
from .model_native_user_block_response import ModelNativeUserBlockResponse
from .model_notification_response import ModelNotificationResponse
from .model_notification_template_response import ModelNotificationTemplateResponse
from .model_notification_topic_response import ModelNotificationTopicResponse
from .model_notification_topic_response_v1 import ModelNotificationTopicResponseV1
from .model_notification_with_template_request import (
    ModelNotificationWithTemplateRequest,
)
from .model_notification_with_template_request_v1 import (
    ModelNotificationWithTemplateRequestV1,
)
from .model_outgoing_friends_with_time_data import ModelOutgoingFriendsWithTimeData
from .model_pagination import ModelPagination
from .model_put_global_configuration_request import ModelPutGlobalConfigurationRequest
from .model_template_content import ModelTemplateContent
from .model_template_localization import ModelTemplateLocalization
from .model_template_localization_response import ModelTemplateLocalizationResponse
from .model_template_response import ModelTemplateResponse
from .model_topic_by_namespaces_response import ModelTopicByNamespacesResponse
from .model_update_template_request import ModelUpdateTemplateRequest
from .model_update_topic_request import ModelUpdateTopicRequest
from .model_user_accept_friend_request import ModelUserAcceptFriendRequest
from .model_user_cancel_friend_request import ModelUserCancelFriendRequest
from .model_user_get_friendship_status_response import (
    ModelUserGetFriendshipStatusResponse,
)
from .model_user_platform_info import ModelUserPlatformInfo
from .model_user_reject_friend_request import ModelUserRejectFriendRequest
from .model_user_request_friend_request import ModelUserRequestFriendRequest
from .model_user_unfriend_request import ModelUserUnfriendRequest
from .model_user_with_platform_info import ModelUserWithPlatformInfo
from .models_admin_add_profanity_filter_into_list_request import (
    ModelsAdminAddProfanityFilterIntoListRequest,
)
from .models_admin_add_profanity_filters_filter_request import (
    ModelsAdminAddProfanityFiltersFilterRequest,
)
from .models_admin_add_profanity_filters_request import (
    ModelsAdminAddProfanityFiltersRequest,
)
from .models_admin_create_profanity_list_request import (
    ModelsAdminCreateProfanityListRequest,
)
from .models_admin_delete_profanity_filter_request import (
    ModelsAdminDeleteProfanityFilterRequest,
)
from .models_admin_get_profanity_list_filters_v1_response import (
    ModelsAdminGetProfanityListFiltersV1Response,
)
from .models_admin_get_profanity_lists_list_response import (
    ModelsAdminGetProfanityListsListResponse,
)
from .models_admin_set_profanity_rule_for_namespace_request import (
    ModelsAdminSetProfanityRuleForNamespaceRequest,
)
from .models_admin_update_profanity_list import ModelsAdminUpdateProfanityList
from .models_admin_verify_message_profanity_request import (
    ModelsAdminVerifyMessageProfanityRequest,
)
from .models_admin_verify_message_profanity_response import (
    ModelsAdminVerifyMessageProfanityResponse,
)
from .models_block_player_request import ModelsBlockPlayerRequest
from .models_blocked_by_player_data import ModelsBlockedByPlayerData
from .models_blocked_player_data import ModelsBlockedPlayerData
from .models_config import ModelsConfig
from .models_config_list import ModelsConfigList
from .models_config_req import ModelsConfigReq
from .models_create_config_request import ModelsCreateConfigRequest
from .models_create_config_response import ModelsCreateConfigResponse
from .models_debug_profanity_filter_request import ModelsDebugProfanityFilterRequest
from .models_get_all_player_blocked_by_users_response import (
    ModelsGetAllPlayerBlockedByUsersResponse,
)
from .models_get_all_player_blocked_users_response import (
    ModelsGetAllPlayerBlockedUsersResponse,
)
from .models_get_all_player_session_attribute_response import (
    ModelsGetAllPlayerSessionAttributeResponse,
)
from .models_get_bulk_all_player_blocked_users_request import (
    ModelsGetBulkAllPlayerBlockedUsersRequest,
)
from .models_get_bulk_all_player_blocked_users_response import (
    ModelsGetBulkAllPlayerBlockedUsersResponse,
)
from .models_get_config_response import ModelsGetConfigResponse
from .models_get_lobby_ccu_response import ModelsGetLobbyCcuResponse
from .models_get_player_session_attribute_response import (
    ModelsGetPlayerSessionAttributeResponse,
)
from .models_import_config_response import ModelsImportConfigResponse
from .models_list_blocked_player_request import ModelsListBlockedPlayerRequest
from .models_party_data import ModelsPartyData
from .models_party_put_custom_attributes_request import (
    ModelsPartyPUTCustomAttributesRequest,
)
from .models_party_put_limit_size_request import ModelsPartyPUTLimitSizeRequest
from .models_profanity_filter import ModelsProfanityFilter
from .models_profanity_rule import ModelsProfanityRule
from .models_set_player_session_attribute_request import (
    ModelsSetPlayerSessionAttributeRequest,
)
from .models_unblock_player_request import ModelsUnblockPlayerRequest
from .models_update_config_request import ModelsUpdateConfigRequest
from .models_update_config_response import ModelsUpdateConfigResponse
from .response_error import ResponseError
from .restapi_error_response_body import RestapiErrorResponseBody
from .restapi_error_response_v1 import RestapiErrorResponseV1



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsChatSnapshots
from ..models import RestapiErrorResponseBody

from ..operations.moderation import AdminDeleteChatSnapshot
from ..operations.moderation import AdminGetChatSnapshot
from ..operations.moderation import PublicGetChatSnapshot


@same_doc_as(AdminDeleteChatSnapshot)
def admin_delete_chat_snapshot(
    chat_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin delete chat snapshot (adminDeleteChatSnapshot)

    Delete the chat snapshot

    Properties:
        url: /chat/v1/admin/namespaces/{namespace}/snapshot/{chatId}

        method: DELETE

        tags: ["moderation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteChatSnapshot.create(
        chat_id=chat_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteChatSnapshot)
async def admin_delete_chat_snapshot_async(
    chat_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin delete chat snapshot (adminDeleteChatSnapshot)

    Delete the chat snapshot

    Properties:
        url: /chat/v1/admin/namespaces/{namespace}/snapshot/{chatId}

        method: DELETE

        tags: ["moderation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteChatSnapshot.create(
        chat_id=chat_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetChatSnapshot)
def admin_get_chat_snapshot(
    chat_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get chat snapshot (adminGetChatSnapshot)

    Get the chat snapshot

    Properties:
        url: /chat/v1/admin/namespaces/{namespace}/snapshot/{chatId}

        method: GET

        tags: ["moderation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsChatSnapshots (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetChatSnapshot.create(
        chat_id=chat_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetChatSnapshot)
async def admin_get_chat_snapshot_async(
    chat_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get chat snapshot (adminGetChatSnapshot)

    Get the chat snapshot

    Properties:
        url: /chat/v1/admin/namespaces/{namespace}/snapshot/{chatId}

        method: GET

        tags: ["moderation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsChatSnapshots (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetChatSnapshot.create(
        chat_id=chat_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetChatSnapshot)
def public_get_chat_snapshot(
    chat_id: str,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public get chat snapshot (publicGetChatSnapshot)

    Get the chat snapshot

    Properties:
        url: /chat/v1/public/namespaces/{namespace}/topic/{topic}/snapshot/{chatId}

        method: GET

        tags: ["moderation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsChatSnapshots (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetChatSnapshot.create(
        chat_id=chat_id,
        topic=topic,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetChatSnapshot)
async def public_get_chat_snapshot_async(
    chat_id: str,
    topic: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """public get chat snapshot (publicGetChatSnapshot)

    Get the chat snapshot

    Properties:
        url: /chat/v1/public/namespaces/{namespace}/topic/{topic}/snapshot/{chatId}

        method: GET

        tags: ["moderation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        chat_id: (chatId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        topic: (topic) REQUIRED str in path

    Responses:
        200: OK - ModelsChatSnapshots (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetChatSnapshot.create(
        chat_id=chat_id,
        topic=topic,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ApiFleetRegionalServerCounts(Model):
    """Api fleet regional server counts (api.FleetRegionalServerCounts)

    Properties:
        claimed_server_count: (claimedServerCount) REQUIRED int

        ready_server_count: (readyServerCount) REQUIRED int

        region: (region) REQUIRED str

        running_vm_count: (runningVmCount) REQUIRED int

        target_ds_count: (targetDsCount) REQUIRED int

        target_vm_count: (targetVmCount) REQUIRED int
    """

    # region fields

    claimed_server_count: int  # REQUIRED
    ready_server_count: int  # REQUIRED
    region: str  # REQUIRED
    running_vm_count: int  # REQUIRED
    target_ds_count: int  # REQUIRED
    target_vm_count: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_claimed_server_count(self, value: int) -> ApiFleetRegionalServerCounts:
        self.claimed_server_count = value
        return self

    def with_ready_server_count(self, value: int) -> ApiFleetRegionalServerCounts:
        self.ready_server_count = value
        return self

    def with_region(self, value: str) -> ApiFleetRegionalServerCounts:
        self.region = value
        return self

    def with_running_vm_count(self, value: int) -> ApiFleetRegionalServerCounts:
        self.running_vm_count = value
        return self

    def with_target_ds_count(self, value: int) -> ApiFleetRegionalServerCounts:
        self.target_ds_count = value
        return self

    def with_target_vm_count(self, value: int) -> ApiFleetRegionalServerCounts:
        self.target_vm_count = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "claimed_server_count"):
            result["claimedServerCount"] = int(self.claimed_server_count)
        elif include_empty:
            result["claimedServerCount"] = 0
        if hasattr(self, "ready_server_count"):
            result["readyServerCount"] = int(self.ready_server_count)
        elif include_empty:
            result["readyServerCount"] = 0
        if hasattr(self, "region"):
            result["region"] = str(self.region)
        elif include_empty:
            result["region"] = ""
        if hasattr(self, "running_vm_count"):
            result["runningVmCount"] = int(self.running_vm_count)
        elif include_empty:
            result["runningVmCount"] = 0
        if hasattr(self, "target_ds_count"):
            result["targetDsCount"] = int(self.target_ds_count)
        elif include_empty:
            result["targetDsCount"] = 0
        if hasattr(self, "target_vm_count"):
            result["targetVmCount"] = int(self.target_vm_count)
        elif include_empty:
            result["targetVmCount"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        claimed_server_count: int,
        ready_server_count: int,
        region: str,
        running_vm_count: int,
        target_ds_count: int,
        target_vm_count: int,
        **kwargs,
    ) -> ApiFleetRegionalServerCounts:
        instance = cls()
        instance.claimed_server_count = claimed_server_count
        instance.ready_server_count = ready_server_count
        instance.region = region
        instance.running_vm_count = running_vm_count
        instance.target_ds_count = target_ds_count
        instance.target_vm_count = target_vm_count
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiFleetRegionalServerCounts:
        instance = cls()
        if not dict_:
            return instance
        if "claimedServerCount" in dict_ and dict_["claimedServerCount"] is not None:
            instance.claimed_server_count = int(dict_["claimedServerCount"])
        elif include_empty:
            instance.claimed_server_count = 0
        if "readyServerCount" in dict_ and dict_["readyServerCount"] is not None:
            instance.ready_server_count = int(dict_["readyServerCount"])
        elif include_empty:
            instance.ready_server_count = 0
        if "region" in dict_ and dict_["region"] is not None:
            instance.region = str(dict_["region"])
        elif include_empty:
            instance.region = ""
        if "runningVmCount" in dict_ and dict_["runningVmCount"] is not None:
            instance.running_vm_count = int(dict_["runningVmCount"])
        elif include_empty:
            instance.running_vm_count = 0
        if "targetDsCount" in dict_ and dict_["targetDsCount"] is not None:
            instance.target_ds_count = int(dict_["targetDsCount"])
        elif include_empty:
            instance.target_ds_count = 0
        if "targetVmCount" in dict_ and dict_["targetVmCount"] is not None:
            instance.target_vm_count = int(dict_["targetVmCount"])
        elif include_empty:
            instance.target_vm_count = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiFleetRegionalServerCounts]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiFleetRegionalServerCounts]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiFleetRegionalServerCounts,
        List[ApiFleetRegionalServerCounts],
        Dict[Any, ApiFleetRegionalServerCounts],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "claimedServerCount": "claimed_server_count",
            "readyServerCount": "ready_server_count",
            "region": "region",
            "runningVmCount": "running_vm_count",
            "targetDsCount": "target_ds_count",
            "targetVmCount": "target_vm_count",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "claimedServerCount": True,
            "readyServerCount": True,
            "region": True,
            "runningVmCount": True,
            "targetDsCount": True,
            "targetVmCount": True,
        }

    # endregion static methods
